﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace Example
{
	public class MyViewModel : INotifyPropertyChanged
	{
		public MyViewModel()
		{
			this.SmallImage = new Uri("Images/SmallImage.png", UriKind.Relative);
			this.Image = new Uri("Images/Image.png", UriKind.Relative);
			this.LargeImage = new Uri("Images/LargeImage.png", UriKind.Relative);
		}
		public string Header { get; set; }
		public Uri SmallImage { get; set; }
		public Uri Image { get; set; }
		public Uri LargeImage { get; set; }

		private ContentState _contentState;
		/// <summary>
		///     Gets or sets the name.
		/// </summary>
		public ContentState ContentState
		{
			get
			{
				return this._contentState;
			}
			set
			{
				if (this._contentState != value)
				{
					this._contentState = value;
					OnPropertyChanged("ContentState");
				}
			}
		}

		public static IList<object> GenerateItems()
		{
			var result = new ObservableCollection<object>();
			foreach (var num in Enumerable.Range(1, 12))
			{
				result.Add(new MyViewModel() { Header = String.Format("Item {0}", num) });
			}
			return result;
		}

		/// <summary>
		///     Event for INotifyPropertyChanged.
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged;

		/// <summary>
		///     Raises the INotifyPropertyChanged event.
		/// </summary>
		/// <param name="propertyName">The property to be included in the INotifyPropertyChanged EventArgs.</param>
		protected virtual void OnPropertyChanged(String propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
        

	}
	public enum ContentState
	{
		SmallContent = 1,
		NormalContent = 0,
		LargeContent = 2
	}
}
